@@ -9,3 +9,6 @@ class Product:
 
     def __init__(self, attrs=None):
         self.__dict__ = attrs or dict()
+
+    def __str__(self):
+        return str(self.__dict__)
